Contributing
------------

1. Fork the repository and clone it locally.
2. Install `tox` testing framework: `pip install tox`.
3. Go to the root of project and run: `tox`.
   It should be successful. If it is not, something is wrong.
4. Make changes to code, documentation, etc.
5. Run `tox` to apply checks. If it is not successful, please fix it or ask
   advices.
6. Commit changes to your forked repository.
7. Submit a Pull Request on GitHub.
